﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using MRP2Plugin;
using MRP2;

namespace PickyRecorder
{
    public class PickyRecorder : Plugin
    {
        List<Script.Events> FilteredPlayEvents = new List<Script.Events>();
        List<Script.Events> FilteredRecordEvents = new List<Script.Events>();

        #region "IPlugin Fields"

        public override string Author
        {
            get { return "Nemex"; }
        }

        public override string Description
        {
            get { return "Filters out events from being recorded\\played"; }
        }

        public override bool HasSettings
        {
            get { return true; }
        }

        public override string Name
        {
            get { return "PickyRecorder"; }
        }
        #endregion

        public override bool OnPlayEventProcess(int index, ref MRP2.Script.ScriptItem ev)
        {
            if (FilteredPlayEvents.Contains(ev.EventType)) return true; //If true is returned, event is consumed and MRP does not process it
            return false;
        }

        public override void OnPluginClose() {}

        public override System.Windows.Forms.ToolStripMenuItem OnPluginCreateToolStripMenuItem()
        {
            //This menu item will be created under MRP Tools > Plugins menu strip
            ToolStripMenuItem pluginMenu = new ToolStripMenuItem("Filter Events");
            pluginMenu.Click += new EventHandler(PluginMenu_Click); //We handle the menu click event by attaching this handler
            return pluginMenu; //We return the menu item we want MRP to create in the Plugins parent menu strip

            //Return 'null' if no menu needs to be created
        }

        private void PluginMenu_Click(object sender, EventArgs e)
        {
            OnPluginSettings(); //When user clicks on the plugin menu item, show the default plugin settings
        }

        public override void OnPluginLoad()
        {

        }

        public override void OnPluginSettings()
        {
            if (Disabled)
                MessageBox.Show("PickyRecorder is not enabled! events will not be filtered out - to enable PickyRecorder open the Plugins Manager (Ctrl + M) > select 'PickyRecorder' > click on the 'Enable plugin' button.", "PickyRecorder disabled", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);

            SettingsDialog settingsDiag = new SettingsDialog();

            settingsDiag.FilteredRecordEvents = FilteredRecordEvents;
            settingsDiag.FilteredPlayEvents =  FilteredPlayEvents;

            if (settingsDiag.ShowDialog() == DialogResult.OK)
            {
                FilteredRecordEvents = settingsDiag.FilteredRecordEvents;
                FilteredPlayEvents = settingsDiag.FilteredPlayEvents;
            }
        }

        public override bool OnRecordEventProcess(ref MRP2.Script.ScriptItem ev)
        {
            if (FilteredRecordEvents.Contains(ev.EventType)) return true; //If true is returned, event is consumed and MRP does not process it
            return false;
        }

        public override void OnRecordStart() { }

        public override void OnRecordStop() { }

        public override void OnScriptPlay(int index) { }

        public override void OnScriptStop(int index) { }

        public override string Version { get { return "1.0.0.0"; } }
    }
}

