﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace VariableKeyboard
{
    public partial class SettingsDialog : Form
    {
        public SettingsDialog()
        {
            InitializeComponent();
            VariableType_ComboBox.SelectedIndex = 0;
            FindMethod_ComboBox.SelectedIndex = 0;
        }

        private bool IsIntegerVariable
        {
            get { return VariableType_ComboBox.SelectedIndex > 0; }

        }

        private void VariableType_ComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            IntegerVariableGroupBox.Enabled = IsIntegerVariable;
            if (IsIntegerVariable)
                VariableValue_TextBox.Text = "0";
        }

        private void VariableValue_TextBox_TextChanged(object sender, EventArgs e)
        {
            if (IsIntegerVariable)
            {
                try {
                    Convert.ToInt32(VariableValue_TextBox.Text);
                }
                catch {
                    MessageBox.Show("This value is not an integer!", "Value is not an integer", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                    VariableValue_TextBox.Text = "0";
                }
            }
        }

        private void Create_Button_Click(object sender, EventArgs e)
        {
            if (IsIntegerVariable && VariableValue_TextBox.TextLength == 0)
            {
                MessageBox.Show("An integer variable value cannot be empty. Set '0' for default value.", "Integer variable value is empty", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            if (VariableName_Text.TextLength == 0)
            {
                MessageBox.Show("Variable name is empty. Empty variable names cannot be added","Empty variable name", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            if (VariableKeyboard.ContainsVariableName(VariableName_Text.Text))
            {
                MessageBox.Show("This variable already exists, please write another variable name.", "Variable already exists", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return;
            }

            KeyboardVariable.KeyboardVariableValue value;
            
            if (IsIntegerVariable)
                value = new KeyboardVariable.IntegerValue(Convert.ToInt32(VariableValue_TextBox.Text), (int) IncreaseValue_NumericUpDown.Value);
            else
                value = new KeyboardVariable.StringValue(VariableValue_TextBox.Text);


            KeyboardVariable keyVar = new KeyboardVariable(VariableName_Text.Text, value, (FindMethod_ComboBox.SelectedIndex == 0 ? KeyboardVariable.FindMethods.Contains : KeyboardVariable.FindMethods.Whole));
            VariableKeyboard.keyboardVariables.Add(keyVar);

            Variables_DataGridView.Invalidate();
        }

        private void deleteSelectedToolStripMenuItem_Click(object sender, EventArgs e)
        {
            foreach (DataGridViewRow row in Variables_DataGridView.SelectedRows)
            {
                Variables_DataGridView.Rows.RemoveAt(row.Index);
            }
        }

        private void restoreDefaultValuesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            VariableKeyboard.RestoreDefaultVariableValues();
        }
    }
}
