﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Data;
using MRP2Plugin;

namespace VariableKeyboard
{
    public class VariableKeyboard : Plugin
    {
        public static BindingList<KeyboardVariable> keyboardVariables = new BindingList<KeyboardVariable>();
        public static string LogText = "";

        public static bool ContainsVariableName(string name)
        {
            foreach (KeyboardVariable keyVar in keyboardVariables)
            {
                if (keyVar.Name == name)
                    return true;
            }

            return false;
        }

        public static void RestoreDefaultVariableValues()
        {
            if (MessageBox.Show("Are you sure you want to restore your variables to their default value?", "VariableKeyboard Plugin", MessageBoxButtons.OKCancel, MessageBoxIcon.Information) == DialogResult.OK)
            {
                foreach (KeyboardVariable keyVar in keyboardVariables)
                {
                    keyVar.Value.RestoreDefaultValue();
                }
            }
        }

        #region "Plugin Events"
        /// <summary>
        /// Occurs when plugin closes.
        /// </summary>
        public override void OnPluginClose()
        {
            
        }
        /// <summary>
        /// Occurs when plugin loads.
        /// </summary>
        public override void OnPluginLoad()
        {

        }
        /// <summary>
        /// Occurs when user wants to open plugin settings.
        /// </summary>
        public override void OnPluginSettings()
        {
            SettingsDialog settingsDialog = new SettingsDialog();
            settingsDialog.Variables_DataGridView.DataSource = keyboardVariables;

            if (LogText.Length > 0)
                settingsDialog.ReplaceLog_TextBox.Text = LogText;

            settingsDialog.ShowDialog();
        }
        #endregion
        #region "Plugin Information"
        public override string Version
        {
            get { return "1.0.0.0"; }
        }

        public override string Author
        {
            get { return "Nemex"; }
        }

        public override string Description
        {
            get { return "Use a variable string to type on keyboard!"; }
        }

        public override bool HasSettings
        {
            get { return true; }
        }

        public override string Name
        {
            get { return "VariableKeyboard"; }
        }
        #endregion
        #region "Recording\Playing"
        #region "Record"
        /// <summary>
        /// Occurs when a record event was detected. If true is returned, the event is not being consumed and MRP does not add it.
        /// </summary>
        /// <param name="ev">The event</param>
        /// <returns></returns>
        public override bool OnRecordEventProcess(ref MRP2.Script.ScriptItem ev)
        {
            return false;
        }
        /// <summary>
        /// Occurs when MRP start a recording.
        /// </summary>
        public override void OnRecordStart()
        {

        }
        /// <summary>
        /// Occurs when MRP stops a recording.
        /// </summary>
        public override void OnRecordStop()
        {

        }
        #endregion
        #region "Play"
        /// <summary>
        /// Occurs when a script started to play
        /// </summary>
        /// <param name="index">The script event play index</param>
        public override void OnScriptPlay(int index)
        {

        }
        /// <summary>
        /// Occurs when a script stops.
        /// </summary>
        /// <param name="index">The stopped event index</param>
        public override void OnScriptStop(int index)
        {

        }
        /// <summary>
        /// Occurs when MRP plays a script and starts to process an event. Return true to consume this event and abort MRP from playing it.
        /// </summary>
        /// <param name="index">The event index</param>
        /// <param name="ev">The event</param>
        /// <returns></returns>
        public override bool OnPlayEventProcess(int index, ref MRP2.Script.ScriptItem ev)
        {
            if (ev.EventType == MRP2.Script.Events.TypeKeyboard || ev.EventType == MRP2.Script.Events.StartProcess)
            {
                foreach (KeyboardVariable keyVar in keyboardVariables)
                {
                    bool replaced = false;
                    if (keyVar.FindMethod == KeyboardVariable.FindMethods.Whole)
                    {
                        if (ev.EventParameter == keyVar.Name) //If the event paramter is an exact match
                        {
                            ev.EventParameter = keyVar.Value.ToString();
                            keyVar.Value.PerformAction(); //Variable has been replaced, perform action
                            replaced = true;
                        }
                    }
                    else
                    {
                        if (ev.EventParameter.Contains(keyVar.Name))
                        {
                            ev.EventParameter = ev.EventParameter.Replace(keyVar.Name, keyVar.Value.ToString());
                            keyVar.Value.PerformAction(); //Variable has been replaced, perform action
                            replaced = true;
                        }
                    }

                    if (replaced)
                        LogText += "Replaced variable " + keyVar.Name + " with value \"" + keyVar.Value.ToString() + "\" at event " + index.ToString() + Environment.NewLine;
                }
            }

            return false;
        }
        #endregion
        #endregion
        /// <summary>
        /// Return a ToolStripMenuItem to be populated in the "Plugins" menu.
        /// </summary>
        /// <returns></returns>
        public override System.Windows.Forms.ToolStripMenuItem OnPluginCreateToolStripMenuItem()
        {
            ToolStripMenuItem pluginMenu = new ToolStripMenuItem("VariableKeyboard");
            ToolStripMenuItem settingsMenu = new ToolStripMenuItem("Settings");
            ToolStripMenuItem defaultsMenu = new ToolStripMenuItem("Restore Default Values");
            defaultsMenu.ShortcutKeys = Keys.Control | Keys.Shift | Keys.D;

            pluginMenu.Click += new EventHandler(pluginMenu_Click);
            settingsMenu.Click += new EventHandler(settingsMenu_Click);
            defaultsMenu.Click += new EventHandler(defaultsMenu_Click);

            pluginMenu.DropDownItems.Add(defaultsMenu);
            pluginMenu.DropDownItems.Add(new ToolStripSeparator());
            pluginMenu.DropDownItems.Add(settingsMenu);
            return pluginMenu;
        }

        void defaultsMenu_Click(object sender, EventArgs e)
        {
            RestoreDefaultVariableValues();
        }

        void settingsMenu_Click(object sender, EventArgs e)
        {
            OnPluginSettings();
        }

        void pluginMenu_Click(object sender, EventArgs e)
        {
            
        }

    }
}
